<?php

namespace Litecms\Manufacturer\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Manufacturer\Interfaces\CarManufacturerRepositoryInterface;

class CarManufacturerPublicController extends BaseController
{
    // use CarManufacturerWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\CarManufacturer\Interfaces\CarManufacturerRepositoryInterface $car_manufacturer
     *
     * @return type
     */
    public function __construct(CarManufacturerRepositoryInterface $car_manufacturer)
    {
        $this->repository = $car_manufacturer;
        parent::__construct();
    }

    /**
     * Show car_manufacturer's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $car_manufacturers = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$manufacturer::$car_manufacturer.names'))
            ->view('$manufacturer::public.car_manufacturer.index')
            ->data(compact('$car_manufacturers'))
            ->output();
    }

    /**
     * Show car_manufacturer's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $car_manufacturers = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$manufacturer::$car_manufacturer.names'))
            ->view('$manufacturer::public.car_manufacturer.index')
            ->data(compact('$car_manufacturers'))
            ->output();
    }

    /**
     * Show car_manufacturer.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $car_manufacturer = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$car_manufacturer->name . trans('$manufacturer::$car_manufacturer.name'))
            ->view('$manufacturer::public.car_manufacturer.show')
            ->data(compact('$car_manufacturer'))
            ->output();
    }

}
