<?php

namespace Litecms\Manufacturer\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Manufacturer\Models\CarManufacturer;

class CarManufacturerPolicy
{

    /**
     * Determine if the given user can view the car_manufacturer.
     *
     * @param UserPolicy $user
     * @param CarManufacturer $car_manufacturer
     *
     * @return bool
     */
    public function view(UserPolicy $user, CarManufacturer $car_manufacturer)
    {
        if ($user->canDo('manufacturer.car_manufacturer.view') && $user->isAdmin()) {
            return true;
        }

        return $car_manufacturer->user_id == user_id() && $car_manufacturer->user_type == user_type();
    }

    /**
     * Determine if the given user can create a car_manufacturer.
     *
     * @param UserPolicy $user
     * @param CarManufacturer $car_manufacturer
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('manufacturer.car_manufacturer.create');
    }

    /**
     * Determine if the given user can update the given car_manufacturer.
     *
     * @param UserPolicy $user
     * @param CarManufacturer $car_manufacturer
     *
     * @return bool
     */
    public function update(UserPolicy $user, CarManufacturer $car_manufacturer)
    {
        if ($user->canDo('manufacturer.car_manufacturer.edit') && $user->isAdmin()) {
            return true;
        }

        return $car_manufacturer->user_id == user_id() && $car_manufacturer->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given car_manufacturer.
     *
     * @param UserPolicy $user
     * @param CarManufacturer $car_manufacturer
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CarManufacturer $car_manufacturer)
    {
        return $car_manufacturer->user_id == user_id() && $car_manufacturer->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given car_manufacturer.
     *
     * @param UserPolicy $user
     * @param CarManufacturer $car_manufacturer
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CarManufacturer $car_manufacturer)
    {
        if ($user->canDo('manufacturer.car_manufacturer.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given car_manufacturer.
     *
     * @param UserPolicy $user
     * @param CarManufacturer $car_manufacturer
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CarManufacturer $car_manufacturer)
    {
        if ($user->canDo('manufacturer.car_manufacturer.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
