<?php

namespace Litecms\Manufacturer\Providers;

use Illuminate\Support\ServiceProvider;

class ManufacturerServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'manufacturer');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'manufacturer');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.manufacturer', function ($app) {
            return $this->app->make('Litecms\Manufacturer\Manufacturer');
        });

        // Bind CarManufacturer to repository
        $this->app->bind(
            'Litecms\Manufacturer\Interfaces\CarManufacturerRepositoryInterface',
            \Litecms\Manufacturer\Repositories\Eloquent\CarManufacturerRepository::class
        );        // Bind CarModel to repository
        $this->app->bind(
            'Litecms\Manufacturer\Interfaces\CarModelRepositoryInterface',
            \Litecms\Manufacturer\Repositories\Eloquent\CarModelRepository::class
        );

        $this->app->register(\Litecms\Manufacturer\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Manufacturer\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.manufacturer'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/manufacturer.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/manufacturer')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/manufacturer')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
